/***
* Menu.prg
*
* Simple mouseable, hot key replacement routines for MENU TO
*/

#include "Inkey.ch"
#include "Events.ch"
#include "Colors.ch"
#include "Commands.ch"
#include "Mouse.ch"

STATIC aMenuPrompts := {}
STATIC aMenuColors

#define PROMPT_ROW   1
#define PROMPT_COL   2
#define PROMPT_TEXT  3
#define PROMPT_ACCL  4
#define PROMPT_AMP   5


FUNCTION Prompt(nRow, nCol, cText, nAccl)

LOCAL nWhereAmp
LOCAL cHighlight := ""

  DEFAULT nAccl TO 0
  IF (nWhereAmp := At("&", cText)) > 0
    cText := SubStr(cText, 1, nWhereAmp - 1) + ;
             SubStr(cText, nWhereAmp + 1)
  ENDIF

  Aadd(aMenuPrompts, {nRow, nCol, cText, nAccl, nWhereAmp})

RETURN NIL


FUNCTION Menu(nCurrentPrompt)

LOCAL aPrompt
LOCAL nKey := 0
LOCAL lHadAccl := .F.
LOCAL nAccl
LOCAL nNewPrompt
LOCAL lHadHotKey := .F.
LOCAL aEvent
LOCAL nMouse
LOCAL nPrompt
LOCAL lHadDbl := .F.

  DEFAULT nCurrentPrompt TO 1
  aMenuColors := ColorSplit()

  DispBegin()
  FOR nPrompt := 1 TO Len(aMenuPrompts)
    IF nPrompt == nCurrentPrompt
      HighLight(nPrompt)
    ELSE
      DeHighLight(nPrompt)
    ENDIF
  NEXT
  DispEnd()

  nNewPrompt := nCurrentPrompt
  DO WHILE nKey != K_ENTER .AND. nKey != K_ESC .AND. ;
           !lHadHotKey .AND. !lHadDbl
    aEvent := WaitEvent()
    IF aEvent[EV_TYPE] == EV_KEY
      nKey := aEvent[EV_KEY_VAL]
      IF (nAccl := Ascan(aMenuPrompts, ;
             {|aPrompt| aPrompt[PROMPT_ACCL] == nKey } )) > 0
        nNewPrompt := nAccl
        lHadHotKey := .T.
      ELSE
        DO CASE
          CASE nKey == K_DOWN .OR. nKey == K_RIGHT
            IF nCurrentPrompt == Len(aMenuPrompts)
              IF Set(_SET_WRAP)
                nNewPrompt := 1
              ENDIF
            ELSE
              nNewPrompt++
            ENDIF

          CASE nKey == K_UP .OR. nKey == K_LEFT
            IF nCurrentPrompt == 1
              IF Set(_SET_WRAP)
                nNewPrompt := Len(aMenuPrompts)
              ENDIF
            ELSE
              nNewPrompt--
            ENDIF
        ENDCASE
      ENDIF
    ELSEIF aEvent[EV_TYPE] == EV_SGL_CLICK
      nMouse := Ascan(aMenuPrompts, ;
                      {|aPrompt| aEvent[EV_ROW] == aPrompt[1] ;
                           .AND. aEvent[EV_COL] >= aPrompt[2] ;
                           .AND. aEvent[EV_COL] <= aPrompt[2] + ;
                                 Len(aPrompt[3]) - 1})
      IF nMouse > 0
        nNewPrompt := nMouse
      ENDIF
    ELSEIF aEvent[EV_TYPE] == EV_DBL_CLICK
      nMouse := Ascan(aMenuPrompts, ;
                      {|aPrompt| aEvent[EV_ROW] == aPrompt[1]   ;
                           .AND. aEvent[EV_COL] >= aPrompt[2]   ;
                           .AND. aEvent[EV_COL] <= aPrompt[2] + ;
                                 Len(aPrompt[3]) - 1})
      IF nMouse > 0
        nNewPrompt := nMouse
        lHadDbl := .T.
      ENDIF
    ENDIF

    IF nNewPrompt != nCurrentPrompt
      DeHighlight(nCurrentPrompt)
      Highlight(nNewPrompt)
      nCurrentPrompt := nNewPrompt
    ENDIF

  ENDDO

  aMenuPrompts := {}

RETURN nCurrentPrompt


STATIC FUNCTION HighLight(nPrompt)

LOCAL aPrompt := aMenuPrompts[nPrompt]

  @ aPrompt[PROMPT_ROW], aPrompt[PROMPT_COL] ;
    SAY Substr(aPrompt[PROMPT_TEXT], 1, ;
               aPrompt[PROMPT_AMP] - 1) ;
    COLOR aMenuColors[GET_COLOR]

  @ aPrompt[PROMPT_ROW], ;
    aPrompt[PROMPT_COL] + aPrompt[PROMPT_AMP] - 1 ;
    SAY Substr(aPrompt[PROMPT_TEXT],   ;
               aPrompt[PROMPT_AMP], 1) ;
    COLOR aMenuColors[UNSEL_GET_COLOR]

  @ aPrompt[PROMPT_ROW], ;
    aPrompt[PROMPT_COL] + aPrompt[PROMPT_AMP] ;
    SAY Substr(aPrompt[PROMPT_TEXT], ;
               aPrompt[PROMPT_AMP] + 1) ;
    COLOR aMenuColors[GET_COLOR]

RETURN NIL


STATIC FUNCTION DeHighLight(nPrompt)

LOCAL aPrompt := aMenuPrompts[nPrompt]

  @ aPrompt[PROMPT_ROW], aPrompt[PROMPT_COL] ;
    SAY Substr(aPrompt[PROMPT_TEXT], 1, ;
               aPrompt[PROMPT_AMP] - 1) ;
    COLOR aMenuColors[SAY_COLOR]

  @ aPrompt[PROMPT_ROW],    ;
    aPrompt[PROMPT_COL] +   ;
    aPrompt[PROMPT_AMP] - 1 ;
    SAY Substr(aPrompt[PROMPT_TEXT],    ;
               aPrompt[PROMPT_AMP], 1)  ;
    COLOR aMenuColors[UNSEL_GET_COLOR]

  @ aPrompt[PROMPT_ROW], ;
    aPrompt[PROMPT_COL] + aPrompt[PROMPT_AMP] ;
    SAY Substr(aPrompt[PROMPT_TEXT],          ;
               aPrompt[PROMPT_AMP] + 1)       ;
    COLOR aMenuColors[SAY_COLOR]

RETURN NIL
