** PROG NAME: PREFLITE.PRG.                 **
** Check user's system configuration.       **
** Authors: Richard Grossman and Gil Sidhom **
*
* This program checks:
*
* FoxPro version
* DOS config file (CONFIG.SYS) files setting
* Available RAM
* Disk space
* FoxPro config file (CONFIG.FP)
*
* First the usual stuff:
set talk off
*
**********
*
* Variables for desired settings
*
* Shown here are experimental values, which 
* deliberately cause the start-up tests to fail.
* This is done so that you can see how PREFLITE 
* works when it finds real problems!  In actual 
* practice, use the commented-out values 
* shown below, or use your preferred values.
*
*          Test Value        Recommended Value
dversion = {01/01/01}     && {06/03/92}
dfiles   = 999            && 71
dram     = 10192          && 135
dspace   = 100000000      && 3000000
*
* The use of this next value is explained further 
* on, at the spot where we put it to use.
dconfig  = '* FOXPRO CONFIG FILE 09/01/92 *'
*
**********
*
* Check the FoxPro build date
*
CLEAR
@ 04,02 SAY 'Checking out your hardware and ;
operating system setup.'
@ 06,02 SAY 'Checking the date of your FoxPro:'
*
* Get the full version information from Fox:
vstring     = version(1)
*
* Pull out the part containing the date in form: 
* MMM DD YYYY
vdatestring = SUBSTR(vstring,AT('[',vstring)+1,11)
*
* Pull out the year:
vyear       = RIGHT(vdatestring,4)
*
* Pull out the day:
vday        = SUBSTR(vdatestring,5,2)
*
* Pull out the month as a three-character string 
* (i.e. JAN, FEB, DEC): 
vcmon = LEFT(vdatestring,3)
*
* Translate the month to the number of the month 
* of the year:
mstring = 'Jan,Feb,Mar,Apr,May,Jun,Jul,Aug,Sep, ;
Oct,Nov,Dec'
vmonth  = STRTRAN(STR(((AT(vcmon,mstring)-1)/4)+1,2);
,' ','0')
*
* Form a date as a standard date-type
* character string:
vchardate    = vmonth + '/' + vday + '/' + vyear
*
* Convert to a date y, for comparison purposes:
versiondate = CTOD(vchardate)
*
* Compare to desired version date:
IF versiondate >= dversion
  @ 06,60 SAY '{ Passed'  && Check mark
ELSE
  @ 06,60 SAY 'Failed'
  @ 14,02 SAY 'You have an obsolete build of FoxPro 2.'
  @ 15,02 SAY '? VERSION(1) reveals that your version '
  @ 16,02 SAY vchardate + '. You can get a free update to the'
  @ 17,02 SAY DTOC(dversion) + ' version from Fox Software.'
  @ 18,02 SAY 'Sorry, but this system may fail without it.'
  go_on = 'Yes'
  @ 20,02 SAY 'Do you want to try to continue anyway? Yes/No:' ;
  GET go_on picture '@M Yes,No'
  READ
  IF NOT go_on = 'Yes'
    QUIT
  ELSE
   @ 14,00 CLEAR
  ENDIF
ENDIF
*
**********
*
* Check the DOS file handles setting.
*
@ 07,02 SAY 'Checking FILES setting ;
(as reported by the OS):'
*
IF VAL(SYS(2010)) > dfiles
  @ 07,60 SAY '{ Passed'  && Check mark
ELSE
  @ 07,60 SAY 'Failed'
  @ 14,02 SAY 'CONFIG.SYS problem: Your FILES setting '
  @ 15,02 SAY 'is not high enough.  A minimum of ' ;
  + LTRIM(STR(dfiles,3))
  @ 16,02 SAY 'is suggested.  ;
  current setting: ' + LTRIM(SYS(2010))
  go_on = 'Yes'
  @ 20,02 SAY 'Do you want to try to continue ;
  anyway? Yes/No:' ;
  GET go_on picture '@M Yes,No'
  READ
  IF NOT go_on = 'Yes'
    QUIT
  ELSE
   @ 14,00 CLEAR
  ENDIF
ENDIF
*
**********
*
* Check available RAM.
*
@ 08,02 SAY 'Checking available RAM memory:'
*
* Get value of RAM from FoxPro, then divide by 
* 1024 to translate answer into K:
k_ram = ROUND(VAL(LTRIM(SYS(1001)))/1024,0)

IF k_ram  >= dram
  @ 08,60 SAY '{ Passed'  && Check mark
ELSE
  @ 08,60 SAY 'Failed'
  @ 14,02 SAY 'Memory problem: only ' + ;
  LTRIM(TRNSFORM(k_ram,'999,999')) ;
  + 'K available!'
  @ 15,02 SAY 'Possibly not enough to run this ;
  program successfully.'
  @ 16,02 SAY 'Recommended free memory: ' + ;
  LTRIM(TRANSFORM(dram,'999,999')) ;
  + ' K'
  @ 17,02 SAY 'Proceed at your own risk!'
  go_on = 'Yes'
  @ 20,02 SAY 'Do you want to try to continue ;
  anyway? Yes/No:' ;
  GET go_on picture '@M Yes,No'
  READ
  IF NOT go_on = 'Yes'
    QUIT
  ELSE
    @ 14,00 CLEAR
  ENDIF
ENDIF
*
**********
*
* Check available disk space.
*
@ 09,02 SAY 'Checking available disk space...'
IF diskspace() >= dspace
  @ 09,60 SAY '{ Passed'  && Check mark
ELSE
  @ 09,60 SAY 'Failed'
  @ 14,02 SAY 'Disk space is very low, only ' + ;
  LTRIM(TRANSFORM(DISKSPACE(), '999,999,999')) + ;
  ' bytes available!'
  @ 15,02 SAY 'Recommended: ' + ;
  LTRIM(TRANSFORM(dspace, '999,999,999')) + ;
  ' bytes.'
  @ 16,02 SAY 'Possibly not enough space to run ;
  this program: '
  @ 17,02 SAY 'Proceed at your own risk!'
  go_on = 'Yes'
  @ 20,02 SAY 'Do you want to try to continue ;
  anyway? Yes/No:' ;
  GET go_on picture '@M Yes,No'
  READ
  IF NOT go_on = 'Yes'
    QUIT
  ELSE
    @ 14,00 CLEAR
  ENDIF
ENDIF
*
**********
*
* CONFIG.FP
*
@ 10,02 SAY 'Checking FoxPro configuration ;
settings...' foxcfg = ''
* Check the DOS environment for existence of a ;
SET foxprocfg= setting.
foxcfg = GETENV('foxprocfg')
IF NOT EMPTY(foxcfg)
  cfg_file = SUBSTR(foxcfg,RAT('\',foxcfg)+1)
  cfg_path = SUBSTR(foxcfg,1,RAT('\',foxcfg))
  IF EMPTY(cfg_file) OR NOT FILE(cfg_file)
    foxcfg = cfg_path+'CONFIG.FP'
  ENDIF
ENDIF
* If there wasn't one, check the FoxPro search path.
IF EMPTY(foxcfg)
  foxcfg = FULLPATH('CONFIG.FP')
ENDIF
* If there still wasn't one, check the DOS search path.
IF EMPTY(foxcfg)
  foxcfg = FULLPATH('CONFIG.FP',1)
ENDIF
*
* If the primary CONFIG.FP was found, open the file.
* Otherwise, create one.
*
* Note that if one is created, it will either be 
* where a SET FOXPROCFG said it should be, or else 
* in the current directory.
*
* Note also that if SET FOXPROCFG SAYs there should 
* be one somewhere, and it's not, one will be 
* created there even if there is one in another 
* directory somewhere. In other words, SET FOXPROCFG 
* takes precedence.
*
IF FILE(foxcfg)
  configfile = FOPEN(foxcfg)
ELSE
  configfile = FCREATE(foxcfg)
ENDIF
* Read the first line of the CONFIG file:
linein = UPPER(ALLTRIM(FGETS(configfile)))
*
* If it is not "titled" correctly, then it's the 
* wrong file. This is an alternative to reading 
* and checking every line. Basically, we're SAYing 
* either the file is the one we created, or not.
*
IF linein = dconfig
  = FCLOSE(configfile)
  @ 10,60 SAY '{ Passed'  && Check mark
ELSE
  @ 10,60 SAY 'Failed'
  * Close the file, save it as CONFIG.USR (user),
  * and write a new one
  * from scratch:
  *
  = FCLOSE(CONFIGFILE)
  @ 14,02 SAY 'The expected FoxPro configuration ;
  file (CONFIG.FP) file was not '
  @ 15,02 SAY 'found.  You can try to run without ;
  it, but we strongly recommend'
  @ 16,02 SAY 'that you allow this program to ;
  write a correct CONFIG.FP for you.'
  go_on = 'Yes'
  @ 20,02 SAY 'Okay to write a new CONFIG.FP file? ;
  (Recommended!) Yes/No:' ;   
  GET go_on picture '@M Yes,No'
  READ
  @ 14,00 CLEAR
  IF go_on = 'Yes'
    configpath = SUBS(foxcfg,1,RAT('\',foxcfg))
    userfile = configpath+'CONFIG.USR'
    IF NOT FILE(userfile)
      COPY FILE (foxcfg) TO CONFIG.USR
    ENDIF
    CONFIGFILE = FOPEN(foxcfg,12)
    = FCHSIZE(configfile,0)
    = FSEEK(configfile,0)
    = FPUTS(configfile, dconfig)
    *
    * If there was a config file, we write it out 
    * first, safe in the knowledge
    * that if there is a conflicting statement, 
    * we know that FoxPro uses
    * the last occurrence.
    *
    IF FILE('CONFIG.USR')
      userfile = FOPEN('CONFIG.USR')
      DO WHILE NOT FEOF(userfile)
        = FPUTS(configfile,FGETS(userfile))
      ENDDO
      = FCLOSE(userfile)
    ENDIF
    *
    * Here are some examples of what you might 
    * put in the CONFIG.FP file.
    * But you can put whatever you like here:
    *
    = FPUTS(configfile, 'mvarsiz  = 22')
    = FPUTS(configfile, 'mvcount  = 512')
    = FCLOSE(configfile)
    @ 14,02 SAY "A correct FoxPro configuration ;
    file (CONFIG.FP) wasn't found."
    @ 15,02 SAY "One has been created in the ;
    current directory.  You must now "
    @ 16,02 SAY "restart the program.  This ;
    program will now quit, and you can"
    @ 17,02 SAY "then restart the system."
    WAIT WINDOW 'Ready to quit after you have ;
    read the message.'
    QUIT
  ENDIF
ENDIF
*
**********
*
@ 14,02 SAY 'STARTUP CHECK COMPLETED.'
WAIT WINDOW
*
* EOF
